#
# spec file for package wire
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?rhel} == 8
%global debug_package %{nil}
%endif

%if 0%{?rhel}
# Fix ERROR: No build ID note found in
%undefine _missing_build_ids_terminate_build
%endif

Name:           wire
Version:        0.5.0
Release:        10.3
Summary:        Compile-time Dependency Injection for Go
License:        Apache-2.0
Group:          Development/Languages/Go
URL:            https://github.com/google/wire
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.19
%{?systemd_ordering}
ExcludeArch:    s390

%description
Wire is a code generation tool that automates connecting components using
dependency injection. Dependencies between components are represented in Wire
as function parameters, encouraging explicit initialization instead of global
variables. Because Wire operates without runtime state or reflection, code
written to be used with Wire is useful even for hand-written initialization.

%prep
%autosetup -a1 -n %{name}-%{version}

%build
%goprep github.com/google/wire
%gobuild -mod=vendor "" ...

%install
%goinstall

%if 0%{?rhel} == 8
%check
# Fix OBS debug_package execution.
rm -f %{buildroot}/usr/lib/debug/%{_bindir}/%{name}-%{version}-*.debug
%endif

%files
%defattr(-,root,root)
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Mon Apr 24 2023 Marina Latini <marina.latini@suse.com>
- Always require go >= 1.19 (bsc#1203599)
* Wed Mar  8 2023 Marina Latini <marina.latini@suse.com>
- Build with go >= 1.19 on SUSE Linux Enterprise and
  with go1.18 only on SUSE Linux Enterprise 15 SP3. (bsc#1203599)
* Wed Sep 28 2022 Marina Latini <marina.latini@suse.com>
- Require go1.18 (bsc#1203599, GH#19127)
* Thu Jun 16 2022 Julio González Gil <jgonzalez@suse.com>
- Exclude s390 arch
* Tue Feb 15 2022 Witek Bedyk <witold.bedyk@suse.com>
- Refactor conditional golang BuildRequires for RHEL
* Mon Feb 14 2022 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Disabled debug package build for RHEL.
* Fri Feb 11 2022 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Added alternative golang name to build on RHEL.
* Fri Jan 21 2022 Witek Bedyk <witold.bedyk@suse.com>
- Initial package version 0.5.0 (jsc#SLE-23439, jsc#SLE-23422)
